Module: Flowy::Concern::StepRunner

Included in:
Flowy::Concern
Defined in:
lib/flowy/concern/step_runner.rb

Overview

Internal runtime that wraps a step with hooks, dispatches keyword args from result.data, and converts raised errors into Failures according to the rescue: / on_error: / rescue_errors: contract.